" plugin/drawx.vim
"
" Drawx - Richard Bentley-Green, 26/05/2021
"
" ASCII and Unicode art drawing
"
if exists('g:Drawx_loaded')
  finish
endif
let g:Drawx_loaded = 1

" ----------------------------------
" A large number of 'internal' key mappings are defined. This is the prefix to use for them
let g:Drawx_leaderBase = get(g:, 'Drawx_leaderBase', '<leader>8')

" For details of this, see the same value in ../autoload/drawx.vim
let s:nullCmd = 'v"_y'

" ----------------------------------
" Draw a box
vnoremap <silent> <plug>(DrawXBox) :<C-u>call drawx#vDrawBox(0)<cr>
vnoremap <silent> <plug>(DrawXBoxFill) :<C-u>call drawx#vDrawBox(1)<cr>

" Draw an ellipse (two slightly different shapes)
vnoremap <silent> <plug>(DrawXEllipse) :<C-u>call drawx#vDrawEllipse(0, 0)<cr>
vnoremap <silent> <plug>(DrawXEllipseFill) :<C-u>call drawx#vDrawEllipse(0, 1)<cr>
vnoremap <silent> <plug>(DrawXEllipseInflated) :<C-u>call drawx#vDrawEllipse(1, 0)<cr>
vnoremap <silent> <plug>(DrawXEllipseInflatedFill) :<C-u>call drawx#vDrawEllipse(1, 1)<cr>

" Cut and paste
vnoremap <silent> <plug>(DrawXYank) :<C-u>call drawx#vYank(0)<cr>
vnoremap <silent> <plug>(DrawXCut) :<C-u>call drawx#vYank(1)<cr>
vnoremap <silent> <plug>(DrawXClear) :<C-u>call drawx#vClear()<cr>
nnoremap <silent> <plug>(DrawXPaste) :<C-u>call drawx#nPaste(0)<cr>
vnoremap <silent> <plug>(DrawXPaste) :<C-u>call drawx#vPaste(0)<cr>
nnoremap <silent> <plug>(DrawXPasteStd) :<C-u>call drawx#nPaste(1)<cr>
vnoremap <silent> <plug>(DrawXPasteStd) :<C-u>call drawx#vPaste(1)<cr>

" Start path tracing/drawing
exe 'nnoremap <plug>(DrawXTrace) :<C-u>call drawx#cmdExecute('."'call s:tracePathInit()', '".s:nullCmd.g:Drawx_leaderBase."'".')<cr>'

" ------------------------------------------------------------------------------
" Default mappings

" Draw a box
vmap <silent> <leader>0= <plug>(DrawXBox)
vmap <silent> <leader>0# <plug>(DrawXBoxFill)

" Draw an ellipse (two slightly different shapes)
vmap <silent> <leader>0o <plug>(DrawXEllipse)
vmap <silent> <leader>0* <plug>(DrawXEllipseFill)
vmap <silent> <leader>0O <plug>(DrawXEllipseInflated)
vmap <silent> <leader>0@ <plug>(DrawXEllipseInflatedFill)

" Cut and paste
vmap <silent> <leader>0y <plug>(DrawXYank)
vmap <silent> <leader>0x <plug>(DrawXCut)
vmap <silent> <leader>0d <plug>(DrawXClear)
nmap <silent> <leader>0P <plug>(DrawXPaste)
vmap <silent> <leader>0P <plug>(DrawXPaste)
nmap <silent> <leader>0p <plug>(DrawXPasteStd)
vmap <silent> <leader>0p <plug>(DrawXPasteStd)

" Start path tracing/drawing
nmap <leader>00 <plug>(DrawXTrace)

" ----------------------------------
" Commands

" Set a style based on a supplied single character
command -nargs=1 DrawXStyle call drawx#SetStyleFromChar(<q-args>)

" Set default paste options
command -nargs=* DrawXPasteOptSet call drawx#cPasteOptionsSet(<f-args>)
command DrawXPasteOptReset call drawx#cPasteOptionsReset()

" ----------------------------------
" eof

